@@ -391,7 +391,7 @@ L_BFGS::Optimize(FunctionType& function,
     //
     // But don't do this on the first iteration to ensure we always take at
     // least one descent step.
-    if (itNum > 0 && (arma::norm(gradient, 2) < minGradientNorm))
+    if (arma::norm(gradient, 2) < minGradientNorm)
     {
       Info << "L-BFGS gradient norm too small (terminating successfully)."
           << std::endl;
@@ -409,6 +409,12 @@ L_BFGS::Optimize(FunctionType& function,
 
     // Choose the scaling factor.
     double scalingFactor = ChooseScalingFactor(itNum, gradient, s, y);
+    if (scalingFactor == 0.0)
+    {
+      Info << "L-BFGS scaling factor computed as 0 (terminating successfully)."
+          << std::endl;
+      break;
+    }
 
     // Build an approximation to the Hessian and choose the search
     // direction for the current iteration.
